@@ -8,12 +8,12 @@
  */
 
 #include <algorithm>
+#include <cassert>
 #include <cstring>
+#include <memory>
 #include <sstream>
 #include <string>
-
-#include <boost/shared_ptr.hpp>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
 
 #include <librevenge-stream/librevenge-stream.h>
 
@@ -24,24 +24,21 @@
 #include "EPUBTextElements.h"
 #include "EPUBPath.h"
 
-using boost::shared_ptr;
+using std::shared_ptr;
 
-using librevenge::RVNGInputStream;
 using librevenge::RVNGBinaryData;
 using librevenge::RVNGProperty;
 using librevenge::RVNGPropertyFactory;
 using librevenge::RVNGPropertyList;
 using librevenge::RVNGString;
 
-using std::equal;
-
 namespace libepubgen
 {
 
 namespace
 {
 
-typedef boost::unordered_map<std::string, EPUBEmbeddedImage> ImageHandlerMap_t;
+typedef std::unordered_map<std::string, EPUBEmbeddedImage> ImageHandlerMap_t;
 
 const char *CORE_MEDIA_TYPES[] =
 {
@@ -51,11 +48,6 @@ const char *CORE_MEDIA_TYPES[] =
   "image/svg+xml"
 };
 
-bool operator==(const char *const left, const RVNGString &right)
-{
-  return right == left;
-}
-
 bool operator!=(const char *const left, const RVNGString &right)
 {
   return right != left;
@@ -68,8 +60,8 @@ struct EPUBTextGenerator::Impl : public EPUBGenerator
   Impl(EPUBPackage *package, EPUBSplitMethod method);
 
 private:
-  virtual void startHtmlFile();
-  virtual void endHtmlFile();
+  void startHtmlFile() override;
+  void endHtmlFile() override;
 
 public:
   bool m_inPageSpan;
@@ -128,12 +120,11 @@ EPUBTextGenerator::EPUBTextGenerator(EPUBPackage *const package, const EPUBSplit
 }
 
 EPUBTextGenerator::EPUBTextGenerator(EPUBEmbeddingContact &contact, EPUBPackage *const package)
-  : m_impl(0)
+  : m_impl(nullptr)
 {
   // TODO: implement me
   (void) contact;
   (void) package;
-  assert(0);
 }
 
 EPUBTextGenerator::~EPUBTextGenerator()
